@@ -127,12 +127,12 @@ class FaustAgent():
   async def after_attach(self):
     pass
 
-  def start_measure(self, labels: Dict[str, str]):
+  def start_measure(self, labels: Dict[str, str]={}):
     start = default_timer()
     self.metrics.inbound_counter.inc(labels)
     return start
 
-  def end_measure(self, start: float, labels: Dict[str, str]):
+  def end_measure(self, start: float, labels: Dict[str, str]={}):
     end = default_timer()
     self.metrics.lag_timer.add(labels, end - start)
     self.metrics.processed_counter.inc(labels)
